vgmusic package
===============

Submodules
----------

vgmusic.cli module
------------------

.. automodule:: vgmusic.cli
   :members:
   :undoc-members:
   :show-inheritance:

vgmusic.exceptions module
-------------------------

.. automodule:: vgmusic.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

vgmusic.public module
---------------------

.. automodule:: vgmusic.public
   :members:
   :undoc-members:
   :show-inheritance:

vgmusic.utils module
--------------------

.. automodule:: vgmusic.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vgmusic
   :members:
   :undoc-members:
   :show-inheritance:
